function [outputdata] = Time_normalisation(inputdata,n)
%Time_normalisation - Normliases kinematic data in the time domain to n
%data points.
% Dr Martin Warner, University of Southampton, 2014


%Time_normlisation - Interpolates the kinematic data to the given number of
%data points.

%   Input arguments
%       inputdata = Kinematic data that is to be time normalised
%       n = Number of data points

%   Output
%       outputdata = Time normalised kinematic data

%% Time normlisation
l = length(inputdata);
t0 = linspace(1,l,l); 
t1 = linspace(1,l,n); 
outputdata = interp1(t0,inputdata,t1,'linear');